==> vertx-auth-oauth2-3.9.5-sources.jar: io/vertx/ext/auth/oauth2/providers/SoundcloudAuth.java <==
package io.vertx.ext.auth.oauth2.providers;

import io.vertx.codegen.annotations.VertxGen;
import io.vertx.core.Vertx;
import io.vertx.core.http.HttpClientOptions;
import io.vertx.ext.auth.oauth2.OAuth2Auth;
import io.vertx.ext.auth.oauth2.OAuth2ClientOptions;
import io.vertx.ext.auth.oauth2.OAuth2FlowType;

/**
 * Simplified factory to create an {@link OAuth2Auth} for SoundCloud.
 *
 * @author <a href="mailto:plopes@redhat.com">Paulo Lopes</a>
 */
@VertxGen
public interface SoundcloudAuth {

  /**
   * Create a OAuth2Auth provider for SoundCloud
   *
   * @param clientId     the client id given to you by SoundCloud
   * @param clientSecret the client secret given to you by SoundCloud
   */
  static OAuth2Auth create(Vertx vertx, String clientId, String clientSecret) {
    return create(vertx, clientId, clientSecret, new HttpClientOptions());
  }

  /**
   * Create a OAuth2Auth provider for SoundCloud
   *
   * @param clientId          the client id given to you by SoundCloud
   * @param clientSecret      the client secret given to you by SoundCloud
   * @param httpClientOptions custom http client options
   */
  static OAuth2Auth create(Vertx vertx, String clientId, String clientSecret, HttpClientOptions httpClientOptions) {
    return
      OAuth2Auth.create(vertx, OAuth2FlowType.AUTH_CODE, new OAuth2ClientOptions(httpClientOptions)
        .setSite("https://api.soundcloud.com")
        .setTokenPath("/oauth2/token")
        .setAuthorizationPath("/connect")
        .setUserInfoPath("/me.json")
        .setClientID(clientId)
        .setClientSecret(clientSecret));
  }
}

==> vertx-auth-oauth2-4.5.0-sources.jar: io/vertx/ext/auth/oauth2/providers/SoundcloudAuth.java <==
/*
 * Copyright 2015 Red Hat, Inc.
 *
 *  All rights reserved. This program and the accompanying materials
 *  are made available under the terms of the Eclipse Public License v1.0
 *  and Apache License v2.0 which accompanies this distribution.
 *
 *  The Eclipse Public License is available at
 *  http://www.eclipse.org/legal/epl-v10.html
 *
 *  The Apache License v2.0 is available at
 *  http://www.opensource.org/licenses/apache2.0.php
 *
 *  You may elect to redistribute this code under either of these licenses.
 */
package io.vertx.ext.auth.oauth2.providers;

import io.vertx.codegen.annotations.VertxGen;
import io.vertx.core.Vertx;
import io.vertx.core.http.HttpClientOptions;
import io.vertx.ext.auth.oauth2.OAuth2Auth;
import io.vertx.ext.auth.oauth2.OAuth2Options;
import io.vertx.ext.auth.oauth2.OAuth2FlowType;

/**
 * Simplified factory to create an {@link OAuth2Auth} for SoundCloud.
 *
 * @author <a href="mailto:plopes@redhat.com">Paulo Lopes</a>
 */
@VertxGen
public interface SoundcloudAuth {

  /**
   * Create a OAuth2Auth provider for SoundCloud
   *
   * @param clientId     the client id given to you by SoundCloud
   * @param clientSecret the client secret given to you by SoundCloud
   */
  static OAuth2Auth create(Vertx vertx, String clientId, String clientSecret) {
    return create(vertx, clientId, clientSecret, new HttpClientOptions());
  }

  /**
   * Create a OAuth2Auth provider for SoundCloud
   *
   * @param clientId          the client id given to you by SoundCloud
   * @param clientSecret      the client secret given to you by SoundCloud
   * @param httpClientOptions custom http client options
   */
  static OAuth2Auth create(Vertx vertx, String clientId, String clientSecret, HttpClientOptions httpClientOptions) {
    return
      OAuth2Auth.create(vertx, new OAuth2Options()
        .setHttpClientOptions(httpClientOptions)
        .setFlow(OAuth2FlowType.AUTH_CODE)
        .setClientId(clientId)
        .setClientSecret(clientSecret)
        .setSite("https://api.soundcloud.com")
        .setTokenPath("/oauth2/token")
        .setAuthorizationPath("/connect")
        .setUserInfoPath("/me.json"));
  }
}
